{
const TOOLS_RUNNER_URL = "https://functions.yandexcloud.net/d4esian9gs7m7m80qk1q";
const SHOWDOWN_URL = "https://cdnjs.cloudflare.com/ajax/libs/showdown/2.1.0/showdown.min.js";
const TOOL_ID = "bec9a3ac-d83e-46b2-8910-1a2f04c52659";
const BLOCK_ID = "#rec832381209";
const CARDS_PER_ROW_1200 = "1";
const CARDS_PER_ROW_960 = "1";
const CARDS_PER_ROW_640 = "1";
const CARDS_PER_ROW_480 = "1";
const CARDS_PER_ROW_320 = "1";

function setTextElemText(elem, value) {
  const converter = new showdown.Converter();
  converter.setOption("simpleLineBreaks", true);
  const atom = elem.children(".tn-atom");
  atom.html(converter.makeHtml(String(value)));
  atom.find("blockquote").css({
    "white-space": "normal",
    "border-left": "3px solid #333333",
    "padding-left": "20px",
  });
}

function setTextElemLink(elem, value) {
  const atom = elem.children(".tn-atom");
  atom.contents().wrapAll(`<a href="${value}" style="color:inherit;" />`);
}

function setButtonElemText(elem, value) {
  if (!value) {
    elem.remove();
    return;
  }
  const atom = elem.children(".tn-atom");
  atom.text(String(value));
}

function setButtonElemLink(elem, value) {
  if (!value) {
    elem.remove();
    return;
  }
  const atom = elem.children(".tn-atom");
  atom.attr("href", value);
}

function setImageElemImage(elem, value) {
  if (!value.length) {
    elem.remove();
    return;
  }
  const image = value[0];

  const atom = elem.children(".tn-atom");
  if (atom.attr("data-zoomable") === "yes") {
    atom.attr("data-img-zoom-url", image);
    atom.addClass("t-zoomable");
  }

  const img = atom.children("img");
  img.attr("src", image);
  img.attr("data-original", image);
}

function setImageElemLink(elem, value) {
  const atom = elem.children(".tn-atom");
  atom.attr("href", value);
}

function setShapeElemImage(elem, value) {
  if (!value.length) {
    elem.remove();
    return;
  }
  const image = value[0];

  const atom = elem.children(".tn-atom");
  if (atom.attr("data-zoomable") === "yes") {
    atom.attr("data-img-zoom-url", image);
    atom.addClass("t-zoomable");
  }
  atom.css("background-image", `url("${image}")`);
  atom.attr("data-original", image);
}

function setShapeElemLink(elem, value) {
  const atom = elem.children(".tn-atom");
  atom.attr("href", value);
}

function setGalleryElemImages(elem, value) {
  if (!value.length) {
    elem.remove();
    return;
  }

  elem.attr(
    "data-field-imgs-value",
    JSON.stringify(
      value.map((url) => {
        return {
          li_img: url,
          li_imgalt: "",
          li_imgnofollow: false,
          li_imgtarget: false,
          li_imgtitle: "",
          li_imgurl: "",
        };
      })
    )
  );
}

function setVideoElemImage(elem, value) {
  const atom = elem.children(".tn-atom");

  if (!value.length) {
    atom.removeAttr("data-atom-video-has-cover");
    atom.removeAttr("data-original");
    atom.css("background-image", ``);
    atom.find(".tn-atom__video-play-link").remove();
    return;
  }

  const image = value[0];
  atom.css("background-image", `url("${image}")`);
  atom.attr("data-original", image);
}

function setVideoElemVideo(elem, attr, value) {
  if (!value.length) {
    elem.remove();
    return;
  }

  const atom = elem.children(".tn-atom");
  atom.find(".tn-atom__videoiframe").empty().attr(attr, value);
}

function setVideoElemVimeoHash(elem, value) {
  const atom = elem.children(".tn-atom");
  atom.find(".tn-atom__videoiframe").attr("data-vimeohash", value);
}

function getScreenStyles(block_id, cols, min_width) {
  const shift = `min((${min_width}px - 100%) / 2, 0px)`;
  const shift2 = `min(${min_width}px - 100%, 100vw - 100%)`;
  return `
        @media screen and (min-width: ${min_width}px) {
            #rec${block_id} .t-rec:nth-of-type(n) {float:left; width: calc(${min_width}px / ${cols} - ${shift}); margin-left: ${shift};}
            #rec${block_id} .t-rec:nth-of-type(${cols}n+1) {margin-left: 0; width: calc(${min_width}px / ${cols} - ${shift});}
            #rec${block_id} .t-rec:nth-of-type(${cols}n) {width: calc(${min_width}px / ${cols} - ${shift2});}
        }
    `;
}

function translateLoadMore(lang) {
  const translations = {
    EN: "Load more",
    RU: "Загрузить ещё",
    FR: "Charger plus",
    DE: "Mehr laden",
    ES: "Carga más",
    PT: "Carregue mais",
    UK: "Завантажити ще",
    JA: "もっと読み込む",
    ZH: "裝載更多",
  };
  if (lang && translations[lang]) {
    return translations[lang];
  } else {
    return translations.EN;
  }
}

$(document).ready(function () {
  const tool_id = TOOL_ID;
  const block_id = BLOCK_ID.substring(4);
  const block = $(`#rec${block_id}`);
  const style = block.children("style").html();

  block.find("script").remove();
  block.children("style").empty();
  block.removeClass("r r_hidden");

  block
    .wrap(
      `<div id="collabza_rec${block_id}"><div id="rec${block_id}" class="r"></div></div>`
    )
    .remove();
  const collabza_wrapper = $(`#collabza_rec${block_id}`);
  const container_template = $(`#rec${block_id}`);
  container_template.append(
    `<style>
            #rec${block_id} {width: 100%; display: inline-block; vertical-align: top; background-color: ${block.css(
      "background-color"
    )}}
            ${getScreenStyles(block_id, CARDS_PER_ROW_320, 320)}
            ${getScreenStyles(block_id, CARDS_PER_ROW_480, 480)}
            ${getScreenStyles(block_id, CARDS_PER_ROW_640, 640)}
            ${getScreenStyles(block_id, CARDS_PER_ROW_960, 960)}
            ${getScreenStyles(block_id, CARDS_PER_ROW_1200, 1200)}
            #rec${block_id} .collabza_load_more,.collabza_loading {clear: both; width: 100%; padding-top: 20px; padding-bottom: 20px; text-align: center;}
        </style>`
  );

  const project_id = $("#allrecords").attr("data-tilda-project-id");
  const profile = JSON.parse(
    localStorage.getItem(`tilda_members_profile${project_id}`) ||
      localStorage.getItem("memberarea_profile") ||
      "{}"
  );
  profile["login"] = encodeURIComponent(profile["login"]);
  ["groups", "courses"].forEach((key) => delete profile[key]);

  let container;
  let filters;

  function initLoadMore(offset) {
    if (!offset) {
      return;
    }

    const load_more = $(
      `<div class="t-btn collabza_load_more">${translateLoadMore(
        window.tildaBrowserLang
      )}</div>`
    );
    load_more.click(function () {
      load_more.remove();
      loadMore({ data: { offset: offset } });
    });
    load_more.appendTo(container);
  }

  function loadMore(event) {
    const loading = $(`<div class="t-btn collabza_loading">...</div>`);
    loading.appendTo(container);
    $.post(
      TOOLS_RUNNER_URL,
      JSON.stringify({
        tool_id: tool_id,
        profile: profile,
        project_id: project_id,
        referer: document.location.origin,
        user_agent: navigator.userAgent,
        filters: filters,
        offset: event.data.offset,
      }),
      function (data) {
        loading.remove();
        const index_offset = container.find(".t-rec").length;
        data.records?.forEach(function (record, index_cnt) {
          const index = index_offset + index_cnt;
          const item_rec_id = `${block_id}_${index}`;
          item = block.clone().attr("id", `rec${item_rec_id}`);
          item.children("style").html(style.replaceAll(block_id, item_rec_id));
          item.find(".t396__artboard").attr("data-artboard-recid", item_rec_id);
          for (let field in record) {
            const value = record[field];

            if (field.startsWith("class_text")) {
              const selector = field.slice("class_text".length);
              setTextElemText(
                item.find(`${selector}[data-elem-type="text"]`),
                value
              );
              setButtonElemText(
                item.find(`${selector}[data-elem-type="button"]`),
                value
              );
            } else if (field.startsWith("class_images")) {
              const selector = field.slice("class_images".length);
              setImageElemImage(
                item.find(`${selector}[data-elem-type="image"]`),
                value
              );
              setShapeElemImage(
                item.find(`${selector}[data-elem-type="shape"]`),
                value
              );
              setGalleryElemImages(
                item.find(`${selector}[data-elem-type="gallery"]`),
                value
              );
              setVideoElemImage(
                item.find(`${selector}[data-elem-type="video"]`),
                value
              );
            } else if (field.startsWith("class_link")) {
              const selector = field.slice("class_link".length);
              setTextElemLink(
                item.find(`${selector}[data-elem-type="text"]`),
                value
              );
              setImageElemLink(
                item.find(`${selector}[data-elem-type="image"]`),
                value
              );
              setShapeElemLink(
                item.find(`${selector}[data-elem-type="shape"]`),
                value
              );
              setButtonElemLink(
                item.find(`${selector}[data-elem-type="button"]`),
                value
              );
            } else if (field.startsWith("class_video_url")) {
              const selector = field.slice("class_video_url".length);
              setVideoElemVideo(
                item.find(`${selector}[data-elem-type="video"]`),
                "data-mp4video",
                value
              );
            } else if (field.startsWith("class_vimeo_hash")) {
              const selector = field.slice("class_vimeo_hash".length);
              setVideoElemVimeoHash(
                item.find(`${selector}[data-elem-type="video"]`),
                value
              );
            } else {
              for (const hosting of [
                "youtube",
                "vimeo",
                "rutube",
                "kinescope",
                "vkvideo",
              ]) {
                if (field.startsWith(`class_${hosting}_id`)) {
                  const selector = field.slice(`class_${hosting}_id`.length);
                  setVideoElemVideo(
                    item.find(`${selector}[data-elem-type="video"]`),
                    `data-${hosting}id`,
                    value
                  );
                  break;
                }
              }
            }
          }
          item.appendTo(container);
          t396_init(`${block_id}_${index}`);
          window.dispatchEvent(new Event("resize"));
        });
        initLoadMore(data.offset);
        container.trigger("collabza_loaded");
      }
    ).fail(function (data) {
      container.text(
        `Collabza error (${BLOCK_ID}): ${data?.responseJSON?.message}`
      );
      container.css("text-align", "center");
    });
  }

  collabza_wrapper.on("collabza_init", function () {
    container = container_template.clone();
    collabza_wrapper.empty().append(container);
    filters = new URLSearchParams(window.location.search).get(
      `filters${block_id}`
    );
    $.getScript(SHOWDOWN_URL, function () {
      loadMore({ data: { offset: null } });
    });
  });
  collabza_wrapper.trigger("collabza_init");
});
}
